/*
 * Copyright (c) 2007-2010 Sonatype, Inc. All rights reserved.
 *
 * "Sonatype" is a trademark of Sonatype, Inc.
 */

package org.sonatype.tycho.p2.bridge.plugin;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

import org.sonatype.tycho.p2.bridge.client.P2DirectorFactory;
import org.sonatype.tycho.p2.bridge.facade.P2Director;
import org.sonatype.tycho.p2.eclipse.bridge.EclipseInstance;

public abstract class DirectorRunningMojo
    extends WithinEclipseRunningProjectBasedMojo
{

    /**
     * @component
     */
    private P2DirectorFactory p2DirectorFactory;

    @Override
    protected void doWithEclipse( final EclipseInstance eclipse )
    {
        final P2Director p2Director = p2DirectorFactory.create( eclipse );

        final String[] arguments = getArguments();

        getLog().debug( String.format( "P2 director parameters: %s", Arrays.toString( arguments ) ) );

        p2Director.run( new PluginLogProxy( getLog() ), arguments );
    }

    abstract String[] getArguments();

    static String[] toArray( final Map<String, String> arguments )
    {
        final List<String> args = new ArrayList<String>();
        if ( arguments != null )
        {
            for ( final Map.Entry<String, String> entry : arguments.entrySet() )
            {
                args.add( "-" + entry.getKey() );
                if ( entry.getValue() != null )
                {
                    args.add( entry.getValue() );
                }
            }
        }
        return args.toArray( new String[args.size()] );
    }

}
