/*
 * Copyright (c) 2007-2010 Sonatype, Inc. All rights reserved.
 *
 * "Sonatype" is a trademark of Sonatype, Inc.
 */

package org.sonatype.tycho.p2.bridge.plugin;

import java.io.File;

import org.codehaus.plexus.util.StringUtils;
import org.sonatype.tycho.p2.bridge.client.P2ProfileRegistryFactory;
import org.sonatype.tycho.p2.bridge.facade.P2ProfileRegistry;
import org.sonatype.tycho.p2.bridge.facade.ProfileTimestamp;
import org.sonatype.tycho.p2.eclipse.bridge.EclipseInstance;

/**
 * @goal history
 * @phase process-resources
 * @requiresProject false
 */
public class HistoryMojo
    extends WithinEclipseRunningMojo
{

    /**
     * @parameter expression="${location}" default-value="${project.build.directory}/tycho-p2/p2-install-folder"
     * @required
     */
    protected File location;

    /**
     * @parameter
     */
    private String profile;

    /**
     * @component
     */
    private P2ProfileRegistryFactory p2ProfileRegistryFactory;

    /**
     * @component
     */
    private Console console;

    @Override
    protected void doWithEclipse( final EclipseInstance eclipse )
    {
        console.printHeader( String.format( "Location %s history:", location.getAbsolutePath() ) );

        final P2ProfileRegistry p2ProfileRegistry = p2ProfileRegistryFactory.create( eclipse );

        if ( StringUtils.isBlank( profile ) )
        {
            final String[] profileIds = p2ProfileRegistry.getProfileIds( location );
            for ( final String profileId : profileIds )
            {
                console.print( profileId );
                listTimestamp( p2ProfileRegistry, location, profileId );
            }
        }
        else
        {
            listTimestamp( p2ProfileRegistry, location, profile );
        }

        console.print();
    }

    private void listTimestamp( final P2ProfileRegistry p2ProfileRegistry, final File location, final String profile )
    {
        final ProfileTimestamp[] timestamps = p2ProfileRegistry.getProfileTimestamps( location, profile );
        if ( timestamps != null )
        {
            for ( final ProfileTimestamp timestamp : timestamps )
            {
                console.print( String.format( "%s", timestamp ) );
            }
        }
    }
}
