/*
 * Copyright (c) 2007-2010 Sonatype, Inc. All rights reserved.
 *
 * "Sonatype" is a trademark of Sonatype, Inc.
 */

package org.sonatype.tycho.p2.bridge.plugin;

import java.io.File;
import java.util.List;

import org.codehaus.plexus.util.StringUtils;
import org.sonatype.tycho.p2.bridge.client.P2DirectorFactory;
import org.sonatype.tycho.p2.bridge.facade.P2Director;
import org.sonatype.tycho.p2.eclipse.bridge.EclipseInstance;

/**
 * @goal install
 * @phase process-resources
 * @requiresDependencyResolution runtime
 */
public class InstallMojo
    extends WithinEclipseRunningProjectBasedMojo
{

    /**
     * @parameter expression="${location}" default-value="${project.build.directory}/tycho-p2/p2-install-folder/p2"
     * @required
     */
    protected File location;

    /**
     * @parameter default-value="tycho-p2"
     * @required
     */
    private String profile;

    /**
     * @parameter
     * @required
     */
    private List<String> repositories;

    /**
     * @parameter
     */
    private String version;

    /**
     * @parameter
     */
    private String tag;

    /**
     * @component
     */
    private P2DirectorFactory p2DirectorFactory;

    /**
     * @component
     */
    private Console console;

    @Override
    protected void doWithEclipse( final EclipseInstance eclipse )
    {
        if ( version == null )
        {
            console.printHeader( "Upgrading to latest version:" );
        }
        else
        {
            console.printHeader( String.format( "Installing version %s:", version ) );
        }

        final P2Director p2Director = p2DirectorFactory.create( eclipse );

        final PluginLogProxy logProxy = new PluginLogProxy( getLog() );

        if ( StringUtils.isBlank( tag ) )
        {
            if ( version == null )
            {
                tag = "Upgrade to latest version";
            }
            else
            {
                tag = String.format( "Install version %s", version );
            }
        }
        p2Director.install( logProxy, location, profile, version, repositories, tag );

        console.print();
    }

}
