/*
 * Copyright (c) 2007-2010 Sonatype, Inc. All rights reserved.
 *
 * "Sonatype" is a trademark of Sonatype, Inc.
 */

package org.sonatype.tycho.p2.bridge.plugin;

import java.io.File;

import org.sonatype.tycho.p2.bridge.client.P2ProfileRegistryFactory;
import org.sonatype.tycho.p2.bridge.facade.IUIdentity;
import org.sonatype.tycho.p2.bridge.facade.P2ProfileRegistry;
import org.sonatype.tycho.p2.eclipse.bridge.EclipseInstance;

/**
 * @goal list-installed
 * @phase process-resources
 * @requiresDependencyResolution runtime
 */
public class ListInstalledMojo
    extends WithinEclipseRunningProjectBasedMojo
{

    /**
     * @parameter expression="${location}" default-value="${project.build.directory}/tycho-p2/p2-install-folder/p2"
     * @required
     */
    protected File location;

    /**
     * @parameter default-value="tycho-p2"
     */
    private String profile;

    /**
     * @component
     */
    private P2ProfileRegistryFactory p2ProfileRegistryFactory;

    /**
     * @component
     */
    private Console console;

    @Override
    protected void doWithEclipse( final EclipseInstance eclipse )
    {
        console.printHeader( String.format( "Installed in %s :", location.getAbsolutePath() ) );

        final P2ProfileRegistry p2ProfileRegistry = p2ProfileRegistryFactory.create( eclipse );

        final IUIdentity[] installedRoots = p2ProfileRegistry.getInstalledRoots( location, profile );

        if ( installedRoots.length == 1 )
        {
            console.print( installedRoots[0].getVersion() );
        }
        else
        {
            for ( final IUIdentity iu : installedRoots )
            {
                console.print( iu.toString() );
            }
        }

        console.print();
    }
}
