/*
 * Copyright (c) 2007-2010 Sonatype, Inc. All rights reserved.
 *
 * "Sonatype" is a trademark of Sonatype, Inc.
 */

package org.sonatype.tycho.p2.bridge.plugin;

import java.io.File;
import java.util.List;

import org.sonatype.tycho.p2.bridge.client.P2DirectorFactory;
import org.sonatype.tycho.p2.bridge.client.P2ProfileRegistryFactory;
import org.sonatype.tycho.p2.bridge.facade.IUIdentity;
import org.sonatype.tycho.p2.bridge.facade.P2Director;
import org.sonatype.tycho.p2.bridge.facade.P2ProfileRegistry;
import org.sonatype.tycho.p2.bridge.facade.ProfileTimestamp;
import org.sonatype.tycho.p2.eclipse.bridge.EclipseInstance;

/**
 * @goal rollback
 * @phase process-resources
 * @requiresDependencyResolution runtime
 */
public class RollbackMojo
    extends WithinEclipseRunningProjectBasedMojo
{

    /**
     * @parameter expression="${location}" default-value="${project.build.directory}/tycho-p2/p2-install-folder/p2"
     * @required
     */
    protected File location;

    /**
     * @parameter default-value="tycho-p2"
     * @required
     */
    private String profile;

    /**
     * @parameter
     * @required
     */
    private List<String> repositories;

    /**
     * @parameter
     * @required
     */
    private String timestamp;

    /**
     * @parameter
     */
    private String tag;

    /**
     * @component
     */
    private P2DirectorFactory p2DirectorFactory;

    /**
     * @component
     */
    private P2ProfileRegistryFactory p2ProfileRegistryFactory;

    /**
     * @component
     */
    private Console console;

    @Override
    protected void doWithEclipse( final EclipseInstance eclipse )
    {
        console.printHeader( String.format( "Rollback to %s:", timestamp ) );

        final P2Director p2Director = p2DirectorFactory.create( eclipse );
        final P2ProfileRegistry p2ProfileRegistry = p2ProfileRegistryFactory.create( eclipse );

        final PluginLogProxy logProxy = new PluginLogProxy( getLog() );

        Long actualTimestamp = null;
        final ProfileTimestamp[] timestamps = p2ProfileRegistry.getProfileTimestamps( location, profile );
        if ( timestamps != null )
        {
            for ( final ProfileTimestamp profileTimestamp : timestamps )
            {
                if ( timestamp.equals( profileTimestamp.getTag() ) )
                {
                    actualTimestamp = profileTimestamp.getTimestamp();
                }
                else
                {
                    for ( final IUIdentity iu : profileTimestamp.getRoots() )
                    {
                        if ( timestamp.equals( iu.toString() ) || timestamp.equals( iu.getVersion() ) )
                        {
                            actualTimestamp = profileTimestamp.getTimestamp();
                        }
                    }
                }
            }
        }
        if ( actualTimestamp == null )
        {
            try
            {
                actualTimestamp = Long.valueOf( timestamp );
            }
            catch ( final NumberFormatException ignore )
            {
                throw new RuntimeException( String.format( "Rollback timestamp [%s] is not a valid tag", timestamp ) );
            }
        }
        if ( tag == null )
        {
            tag = String.format( "Rollback to %s", actualTimestamp );
        }

        p2Director.rollback( logProxy, location, profile, actualTimestamp, repositories, tag );

        console.print();
    }
}
